@@ -103,7 +103,7 @@ class HTTPPost
             // sign the response - this must be done after encrypting the assertion
             // we insert the signature before the saml2p:Status element
             $statusElements = XML::getDOMChildren($responseroot, 'Status', '@saml1p');
-            assert('count($statusElements) === 1');
+            assert(count($statusElements) === 1);
             $signer->sign($responseroot, $responseroot, $statusElements[0]);
         } else {
             // Sign the assertion
@@ -130,7 +130,7 @@ class HTTPPost
      */
     public function decodeResponse($post)
     {
-        assert('is_array($post)');
+        assert(is_array($post));
 
         if (!array_key_exists('SAMLResponse', $post)) {
             throw new \Exception('Missing required SAMLResponse parameter.');
