@@ -9,8 +9,6 @@
  */
 class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception
 {
-
-
     /**
      * The error code.
      *
@@ -18,7 +16,6 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception
      */
     private $errorCode;
 
-
     /**
      * The http code.
      *
@@ -26,7 +23,6 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception
      */
     protected $httpCode = 500;
 
-
     /**
      * The error title tag in dictionary.
      *
@@ -34,7 +30,6 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception
      */
     private $dictTitle;
 
-
     /**
      * The error description tag in dictionary.
      *
@@ -42,7 +37,6 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception
      */
     private $dictDescr;
 
-
     /**
      * The name of module that threw the error.
      *
@@ -50,7 +44,6 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception
      */
     private $module = null;
 
-
     /**
      * The parameters for the error.
      *
@@ -58,7 +51,6 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception
      */
     private $parameters;
 
-
     /**
      * Name of custom include template for the error.
      *
@@ -66,7 +58,6 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception
      */
     protected $includeTemplate = null;
 
-
     /**
      * Constructor for this error.
      *
@@ -79,7 +70,7 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception
      */
     public function __construct($errorCode, Exception $cause = null, $httpCode = null)
     {
-        assert('is_string($errorCode) || is_array($errorCode)');
+        assert(is_string($errorCode) || is_array($errorCode));
 
         if (is_array($errorCode)) {
             $this->parameters = $errorCode;
@@ -254,9 +245,9 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception
         $this->logError();
 
         $errorData = $this->saveError();
-
         $config = SimpleSAML_Configuration::getInstance();
 
+        $data = array();
         $data['showerrors'] = $config->getBoolean('showerrors', true);
         $data['error'] = $errorData;
         $data['errorCode'] = $this->errorCode;
@@ -289,9 +280,9 @@ class SimpleSAML_Error_Error extends SimpleSAML_Error_Exception
 
         $show_function = $config->getArray('errors.show_function', null);
         if (isset($show_function)) {
-            assert('is_callable($show_function)');
+            assert(is_callable($show_function));
             call_user_func($show_function, $config, $data);
-            assert('FALSE');
+            assert(false);
         } else {
             $t = new SimpleSAML_XHTML_Template($config, 'error.php', 'errors');
             $t->data = array_merge($t->data, $data);
