@@ -1,11 +1,12 @@
 <?php
 /**
  * Exception indicating wrong password given by user.
- * 
+ *
  * @author Thomas Graff <thomas.graff@uninett.no>
  * @package SimpleSAMLphp_base
  *
  */
-class SimpleSAML_Error_InvalidCredential extends SimpleSAML_Error_User{
-	
+class SimpleSAML_Error_InvalidCredential extends SimpleSAML_Error_User
+{
+
 }
