@@ -129,9 +129,9 @@ class SimpleSAML_Session implements Serializable
      *
      * This is an array with authentication data for the various authsources.
      *
-     * @var array|null  Associative array of associative arrays.
+     * @var array  Associative array of associative arrays.
      */
-    private $authData;
+    private $authData = array();
 
 
     /**
@@ -142,8 +142,6 @@ class SimpleSAML_Session implements Serializable
      */
     private function __construct($transient = false)
     {
-        $this->authData = array();
-
         if (php_sapi_name() === 'cli' || defined('STDIN')) {
             $this->trackid = 'CL'.bin2hex(openssl_random_pseudo_bytes(4));
             SimpleSAML\Logger::setTrackId($this->trackid);
@@ -180,7 +178,7 @@ class SimpleSAML_Session implements Serializable
             $globalConfig = SimpleSAML_Configuration::getInstance();
             $checkFunction = $globalConfig->getArray('session.check_function', null);
             if (isset($checkFunction)) {
-                assert('is_callable($checkFunction)');
+                assert(is_callable($checkFunction));
                 call_user_func($checkFunction, $this, true);
             }
         }
@@ -316,7 +314,7 @@ class SimpleSAML_Session implements Serializable
      */
     public static function getSession($sessionId = null)
     {
-        assert('is_string($sessionId) || is_null($sessionId)');
+        assert(is_string($sessionId) || $sessionId === null);
 
         $sh = \SimpleSAML\SessionHandler::getSessionHandler();
 
@@ -339,7 +337,7 @@ class SimpleSAML_Session implements Serializable
             return null;
         }
 
-        assert('$session instanceof self');
+        assert($session instanceof self);
 
         if ($checkToken) {
             $globalConfig = SimpleSAML_Configuration::getInstance();
@@ -362,7 +360,7 @@ class SimpleSAML_Session implements Serializable
             // run session check function if defined
             $checkFunction = $globalConfig->getArray('session.check_function', null);
             if (isset($checkFunction)) {
-                assert('is_callable($checkFunction)');
+                assert(is_callable($checkFunction));
                 $check = call_user_func($checkFunction, $session);
                 if ($check !== true) {
                     SimpleSAML\Logger::warning('Session did not pass check function.');
@@ -417,7 +415,7 @@ class SimpleSAML_Session implements Serializable
      */
     public static function createSession($sessionId)
     {
-        assert('is_string($sessionId)');
+        assert(is_string($sessionId));
         self::$sessions[$sessionId] = null;
     }
 
@@ -482,11 +480,6 @@ class SimpleSAML_Session implements Serializable
 
         $this->dirty = true;
 
-        if (!function_exists('header_register_callback')) {
-            // PHP version < 5.4, can't register the callback
-            return;
-        }
-
         if ($this->callback_registered) {
             // we already have a shutdown callback registered for this object, no need to add another one
             return;
@@ -554,7 +547,7 @@ class SimpleSAML_Session implements Serializable
      */
     public function setRememberMeExpire($expire = null)
     {
-        assert('is_int($expire) || is_null($expire)');
+        assert(is_int($expire) || $expire === null);
 
         if ($expire === null) {
             $globalConfig = SimpleSAML_Configuration::getInstance();
@@ -578,8 +571,8 @@ class SimpleSAML_Session implements Serializable
      */
     public function doLogin($authority, array $data = null)
     {
-        assert('is_string($authority)');
-        assert('is_array($data) || is_null($data)');
+        assert(is_string($authority));
+        assert(is_array($data) || $data === null);
 
         SimpleSAML\Logger::debug('Session: doLogin("'.$authority.'")');
 
@@ -638,7 +631,6 @@ class SimpleSAML_Session implements Serializable
         if (!$this->transient && (!empty($data['RememberMe']) || $this->rememberMeExpire) &&
             $globalConfig->getBoolean('session.rememberme.enable', false)
         ) {
-
             $this->setRememberMeExpire();
         } else {
             try {
@@ -697,8 +689,8 @@ class SimpleSAML_Session implements Serializable
      */
     private function callLogoutHandlers($authority)
     {
-        assert('is_string($authority)');
-        assert('isset($this->authData[$authority])');
+        assert(is_string($authority));
+        assert(isset($this->authData[$authority]));
 
         if (empty($this->authData[$authority]['LogoutHandlers'])) {
             return;
@@ -733,7 +725,7 @@ class SimpleSAML_Session implements Serializable
      */
     public function isValid($authority)
     {
-        assert('is_string($authority)');
+        assert(is_string($authority));
 
         if (!isset($this->authData[$authority])) {
             SimpleSAML\Logger::debug(
@@ -760,12 +752,16 @@ class SimpleSAML_Session implements Serializable
      */
     public function updateSessionCookies($params = null)
     {
+        assert(is_null($params) || is_array($params));
+
         $sessionHandler = \SimpleSAML\SessionHandler::getSessionHandler();
 
         if ($this->sessionId !== null) {
             $sessionHandler->setCookie($sessionHandler->getSessionCookieName(), $this->sessionId, $params);
         }
 
+        $params = array_merge($sessionHandler->getCookieParams(), is_array($params) ? $params : array());
+
         if ($this->authToken !== null) {
             $globalConfig = SimpleSAML_Configuration::getInstance();
             \SimpleSAML\Utils\HTTP::setCookie(
@@ -784,8 +780,8 @@ class SimpleSAML_Session implements Serializable
      */
     public function setAuthorityExpire($authority, $expire = null)
     {
-        assert('isset($this->authData[$authority])');
-        assert('is_int($expire) || is_null($expire)');
+        assert(isset($this->authData[$authority]));
+        assert(is_int($expire) || $expire === null);
 
         $this->markDirty();
 
@@ -808,7 +804,7 @@ class SimpleSAML_Session implements Serializable
      */
     public function registerLogoutHandler($authority, $classname, $functionname)
     {
-        assert('isset($this->authData[$authority])');
+        assert(isset($this->authData[$authority]));
 
         $logout_handler = array($classname, $functionname);
 
@@ -833,8 +829,8 @@ class SimpleSAML_Session implements Serializable
      */
     public function deleteData($type, $id)
     {
-        assert('is_string($type)');
-        assert('is_string($id)');
+        assert(is_string($type));
+        assert(is_string($id));
 
         if (!is_array($this->dataStore)) {
             return;
@@ -866,9 +862,9 @@ class SimpleSAML_Session implements Serializable
      */
     public function setData($type, $id, $data, $timeout = null)
     {
-        assert('is_string($type)');
-        assert('is_string($id)');
-        assert('is_int($timeout) || is_null($timeout) || $timeout === self::DATA_TIMEOUT_SESSION_END');
+        assert(is_string($type));
+        assert(is_string($id));
+        assert(is_int($timeout) || $timeout === null || $timeout === self::DATA_TIMEOUT_SESSION_END);
 
         // clean out old data
         $this->expireData();
@@ -955,8 +951,8 @@ class SimpleSAML_Session implements Serializable
      */
     public function getData($type, $id)
     {
-        assert('is_string($type)');
-        assert('$id === null || is_string($id)');
+        assert(is_string($type));
+        assert($id === null || is_string($id));
 
         if ($id === null) {
             return null;
@@ -994,7 +990,7 @@ class SimpleSAML_Session implements Serializable
      */
     public function getDataOfType($type)
     {
-        assert('is_string($type)');
+        assert(is_string($type));
 
         if (!is_array($this->dataStore)) {
             return array();
@@ -1021,7 +1017,7 @@ class SimpleSAML_Session implements Serializable
      */
     public function getAuthState($authority)
     {
-        assert('is_string($authority)');
+        assert(is_string($authority));
 
         if (!isset($this->authData[$authority])) {
             return null;
@@ -1055,9 +1051,9 @@ class SimpleSAML_Session implements Serializable
      */
     public function addAssociation($idp, array $association)
     {
-        assert('is_string($idp)');
-        assert('isset($association["id"])');
-        assert('isset($association["Handler"])');
+        assert(is_string($idp));
+        assert(isset($association['id']));
+        assert(isset($association['Handler']));
 
         if (!isset($this->associations)) {
             $this->associations = array();
@@ -1084,7 +1080,7 @@ class SimpleSAML_Session implements Serializable
      */
     public function getAssociations($idp)
     {
-        assert('is_string($idp)');
+        assert(is_string($idp));
 
         if (!isset($this->associations)) {
             $this->associations = array();
@@ -1119,8 +1115,8 @@ class SimpleSAML_Session implements Serializable
      */
     public function terminateAssociation($idp, $associationId)
     {
-        assert('is_string($idp)');
-        assert('is_string($associationId)');
+        assert(is_string($idp));
+        assert(is_string($associationId));
 
         if (!isset($this->associations)) {
             return;
@@ -1146,8 +1142,8 @@ class SimpleSAML_Session implements Serializable
      */
     public function getAuthData($authority, $name)
     {
-        assert('is_string($authority)');
-        assert('is_string($name)');
+        assert(is_string($authority));
+        assert(is_string($name));
 
         if (!isset($this->authData[$authority][$name])) {
             return null;
