@@ -97,6 +97,16 @@ abstract class SessionHandler
     abstract public function loadSession($sessionId = null);
 
 
+    /**
+     * Check whether the session cookie is set.
+     *
+     * This function will only return false if is is certain that the cookie isn't set.
+     *
+     * @return bool True if it was set, false if not.
+     */
+    abstract public function hasSessionCookie();
+
+
     /**
      * Set a session cookie.
      *
@@ -129,19 +139,6 @@ abstract class SessionHandler
     }
 
 
-    /**
-     * Check whether the session cookie is set.
-     *
-     * This function will only return false if is is certain that the cookie isn't set.
-     *
-     * @return bool True if it was set, false if not.
-     */
-    public function hasSessionCookie()
-    {
-        return true;
-    }
-
-
     /**
      * Get the cookie parameters that should be used for session cookies.
      *
