@@ -39,8 +39,8 @@ class Memcache extends Store
      */
     public function get($type, $key)
     {
-        assert('is_string($type)');
-        assert('is_string($key)');
+        assert(is_string($type));
+        assert(is_string($key));
 
         return \SimpleSAML_Memcache::get($this->prefix . '.' . $type . '.' . $key);
     }
@@ -56,9 +56,9 @@ class Memcache extends Store
      */
     public function set($type, $key, $value, $expire = null)
     {
-        assert('is_string($type)');
-        assert('is_string($key)');
-        assert('is_null($expire) || (is_int($expire) && $expire > 2592000)');
+        assert(is_string($type));
+        assert(is_string($key));
+        assert($expire === null || (is_int($expire) && $expire > 2592000));
 
         if ($expire === null) {
             $expire = 0;
@@ -76,8 +76,8 @@ class Memcache extends Store
      */
     public function delete($type, $key)
     {
-        assert('is_string($type)');
-        assert('is_string($key)');
+        assert(is_string($type));
+        assert(is_string($key));
 
         \SimpleSAML_Memcache::delete($this->prefix . '.' . $type . '.' . $key);
     }
