@@ -117,8 +117,8 @@ class Metadata
 
         // check attributes is an associative array
         if (isset($contact['attributes'])) {
-            if (empty($contact['attributes']) 
-                || !is_array($contact['attributes']) 
+            if (empty($contact['attributes'])
+                || !is_array($contact['attributes'])
                 || count(array_filter(array_keys($contact['attributes']), 'is_string')) === 0
             ) {
                 throw new \InvalidArgumentException('"attributes" must be an array and cannot be empty.');
@@ -230,7 +230,7 @@ class Metadata
                 continue;
             }
 
-            if (array_key_exists('isDefault', $ep)) {
+            if (isset($ep['isDefault'])) {
                 if ($ep['isDefault'] === true) {
                     // this is the first endpoint with isDefault set to true
                     return $ep;
