@@ -23,7 +23,7 @@ class Validator
     private $x509Certificate;
 
     /**
-     * @var array This variable contains the nodes which are signed.
+     * @var array|null This variable contains the nodes which are signed.
      */
     private $validNodes = null;
 
@@ -48,7 +48,7 @@ class Validator
      */
     public function __construct($xmlNode, $idAttribute = null, $publickey = false)
     {
-        assert('$xmlNode instanceof \DOMNode');
+        assert($xmlNode instanceof \DOMNode);
 
         if ($publickey === null) {
             $publickey = false;
@@ -57,7 +57,7 @@ class Validator
                 'PEM' => $publickey,
             );
         } else {
-            assert('$publickey === FALSE || is_array($publickey)');
+            assert($publickey === false || is_array($publickey));
         }
 
         // Create an XML security object
@@ -111,7 +111,7 @@ class Validator
                  * Check that the response contains a certificate with a matching
                  * fingerprint.
                  */
-                assert('is_array($publickey["certFingerprint"])');
+                assert(is_array($publickey['certFingerprint']));
 
                 $certificate = $objKey->getX509Certificate();
                 if ($certificate === null) {
@@ -162,7 +162,7 @@ class Validator
      */
     private static function calculateX509Fingerprint($x509cert)
     {
-        assert('is_string($x509cert)');
+        assert(is_string($x509cert));
 
         $lines = explode("\n", $x509cert);
 
@@ -205,8 +205,8 @@ class Validator
      */
     private static function validateCertificateFingerprint($certificate, $fingerprints)
     {
-        assert('is_string($certificate)');
-        assert('is_array($fingerprints)');
+        assert(is_string($certificate));
+        assert(is_array($fingerprints));
 
         $certFingerprint = self::calculateX509Fingerprint($certificate);
         if ($certFingerprint === null) {
@@ -216,7 +216,7 @@ class Validator
         }
 
         foreach ($fingerprints as $fp) {
-            assert('is_string($fp)');
+            assert(is_string($fp));
 
             if ($fp === $certFingerprint) {
                 // The fingerprints matched
@@ -243,7 +243,7 @@ class Validator
      */
     public function validateFingerprint($fingerprints)
     {
-        assert('is_string($fingerprints) || is_array($fingerprints)');
+        assert(is_string($fingerprints) || is_array($fingerprints));
 
         if ($this->x509Certificate === null) {
             throw new \Exception('Key used to sign the message was not an X509 certificate.');
@@ -255,7 +255,7 @@ class Validator
 
         // Normalize the fingerprints
         foreach ($fingerprints as &$fp) {
-            assert('is_string($fp)');
+            assert(is_string($fp));
 
             // Make sure that the fingerprint is in the correct format
             $fp = strtolower(str_replace(":", "", $fp));
@@ -274,7 +274,7 @@ class Validator
      */
     public function isNodeValidated($node)
     {
-        assert('$node instanceof \DOMNode');
+        assert($node instanceof \DOMNode);
 
         while ($node !== null) {
             if (in_array($node, $this->validNodes, true)) {
@@ -301,7 +301,7 @@ class Validator
      */
     public function validateCA($caFile)
     {
-        assert('is_string($caFile)');
+        assert(is_string($caFile));
 
         if ($this->x509Certificate === null) {
             throw new \Exception('Key used to sign the message was not an X509 certificate.');
@@ -321,11 +321,12 @@ class Validator
      */
     private static function validateCABuiltIn($certificate, $caFile)
     {
-        assert('is_string($certificate)');
-        assert('is_string($caFile)');
+        assert(is_string($certificate));
+        assert(is_string($caFile));
 
         // Clear openssl errors
-        while (openssl_error_string() !== false);
+        while (openssl_error_string() !== false) {
+        }
 
         $res = openssl_x509_checkpurpose($certificate, X509_PURPOSE_ANY, array($caFile));
 
@@ -358,8 +359,8 @@ class Validator
      */
     private static function validateCAExec($certificate, $caFile)
     {
-        assert('is_string($certificate)');
-        assert('is_string($caFile)');
+        assert(is_string($certificate));
+        assert(is_string($caFile));
 
         $command = array(
             'openssl', 'verify',
@@ -417,8 +418,8 @@ class Validator
      */
     public static function validateCertificate($certificate, $caFile)
     {
-        assert('is_string($certificate)');
-        assert('is_string($caFile)');
+        assert(is_string($certificate));
+        assert(is_string($caFile));
 
         if (!file_exists($caFile)) {
             throw new \Exception('Could not load CA file: ' . $caFile);
