@@ -1,6 +1,6 @@
 <?php
 /**
- * SAML 1.1 remote IdP metadata for simpleSAMLphp.
+ * SAML 1.1 remote IdP metadata for SimpleSAMLphp.
  *
  * Remember to remove the IdPs you don't use from this file.
  *
@@ -10,6 +10,6 @@
 /*
 $metadata['theproviderid-of-the-idp'] = array(
 	'SingleSignOnService'  => 'https://idp.example.org/shibboleth-idp/SSO',
-	'certFingerprint'      => 'c7279a9f28f11380509e072441e3dc55fb9ab864',
+	'certificate'          => 'example.pem',
 );
 */
