@@ -15,7 +15,7 @@ if (!isset($_GET['ticket'])) {
 $state['cas:ticket'] = (string)$_GET['ticket'];
 
 // Find authentication source
-assert('array_key_exists(sspmod_cas_Auth_Source_CAS::AUTHID, $state)');
+assert(array_key_exists(sspmod_cas_Auth_Source_CAS::AUTHID, $state));
 $sourceId = $state[sspmod_cas_Auth_Source_CAS::AUTHID];
 
 $source = SimpleSAML_Auth_Source::getById($sourceId);
