@@ -4,7 +4,7 @@ $this->includeAtTemplateBase('includes/header.php');
 <div class="metadatabox">
     <button data-clipboard-target="#metadata" id="btncp" class="btn topright" style="margin-right: 0.5em;">
         <img src="/<?php echo $this->data['baseurlpath'].'resources/icons/clipboard.svg'; ?>"
-             alt="Copy to clipboard">
+             alt="Copy to clipboard" />
     </button>
     <pre id="metadata">
 $metadata['<?php echo $this->data['m']['metadata-index']; unset($this->data['m']['metadata-index']) ?>'] => <?php
