@@ -36,9 +36,9 @@ class sspmod_ldap_Auth_Process_AttributeAddFromLDAP extends sspmod_ldap_Auth_Pro
 {
 
     /**
-     * LDAP attribute to add to the request attributes
+     * LDAP attributes to add to the request attributes
      *
-     * @var string
+     * @var array
      */
     protected $search_attributes;
 
@@ -137,14 +137,15 @@ class sspmod_ldap_Auth_Process_AttributeAddFromLDAP extends sspmod_ldap_Auth_Pro
      */
     public function process(&$request)
     {
-        assert('is_array($request)');
-        assert('array_key_exists("Attributes", $request)');
+        assert(is_array($request));
+        assert(array_key_exists('Attributes', $request));
 
         $attributes =& $request['Attributes'];
 
         // perform a merge on the ldap_search_filter
-
         // loop over the attributes and build the search and replace arrays
+        $arrSearch = array();
+        $arrReplace = array();
         foreach ($attributes as $attr => $val) {
             $arrSearch[] = '%'.$attr.'%';
 
