@@ -21,8 +21,8 @@ class sspmod_ldap_Auth_Process_AttributeAddUsersGroups extends sspmod_ldap_Auth_
      */
     public function process(&$request)
     {
-        assert('is_array($request)');
-        assert('array_key_exists("Attributes", $request)');
+        assert(is_array($request));
+        assert(array_key_exists('Attributes', $request));
 
         // Log the process
         SimpleSAML\Logger::debug(
@@ -73,11 +73,8 @@ class sspmod_ldap_Auth_Process_AttributeAddUsersGroups extends sspmod_ldap_Auth_
      * @param array $attributes
      * @return array
      */
-    protected function getGroups(array $attributes)
+    protected function getGroups($attributes)
     {
-        // Reference the map, just to make the name shorter
-        $map =& $this->attribute_map;
-
         // Log the request
         SimpleSAML\Logger::debug(
             $this->title . 'Checking for groups based on the best method for the LDAP product.'
@@ -86,58 +83,15 @@ class sspmod_ldap_Auth_Process_AttributeAddUsersGroups extends sspmod_ldap_Auth_
         // Based on the directory service, search LDAP for groups
         // If any attributes are needed, prepare them before calling search method
         switch ($this->product) {
-
             case 'ACTIVEDIRECTORY':
-
-                // Log the AD specific search
-                SimpleSAML\Logger::debug(
-                    $this->title . 'Searching LDAP using ActiveDirectory specific method.'
-                );
-
-                // Make sure the defined dn attribute exists
-                if (!isset($attributes[$map['dn']])) {
-                    throw new SimpleSAML_Error_Exception(
-                        $this->title . 'The DN attribute [' . $map['dn'] .
-                        '] is not defined in the users Attributes: ' . implode(', ', array_keys($attributes))
-                    );
-                }
-
-                // DN attribute must have a value
-                if (!isset($attributes[$map['dn']][0]) || !$attributes[$map['dn']][0]) {
-                    throw new SimpleSAML_Error_Exception(
-                        $this->title . 'The DN attribute [' . $map['dn'] .
-                        '] does not have a [0] value defined. ' . $this->var_export($attributes[$map['dn']])
-                    );
-                }
-
-                // Pass to the AD specific search
-                $groups = $this->searchActiveDirectory($attributes[$map['dn']][0]);
+                $groups = $this->getGroupsActiveDirectory($attributes);
                 break;
-                
             case 'OPENLDAP':
-                // Log the OpenLDAP specific search
-                SimpleSAML\Logger::debug(
-                    $this->title . 'Searching LDAP using OpenLDAP specific method.'
-                );
-                // Print group search string and search for all group names
-                $openldap_base = $this->config->getString('ldap.basedn','ou=groups,dc=example,dc=com');
-                SimpleSAML\Logger::debug(
-                    $this->title . "Searching for groups in ldap.basedn ".$openldap_base." with filter (".$map['memberof']."=".$attributes[$map['username']][0].") and attributes ".$map['member']
-                );
-                $groups = array();
-                try {
-                    // Intention is to filter in 'ou=groups,dc=example,dc=com' for '(memberUid = <value of attribute.username>)' and take only the attributes 'cn' (=name of the group)
-                    $all_groups = $this->getLdap()->searchformultiple( $openldap_base, array($map['memberof'] => $attributes[$map['username']][0]) , array($map['member']));
-                } catch (SimpleSAML_Error_UserNotFound $e) {
-                    break; // if no groups found return with empty (still just initialized) groups array
-                }
-                // run through all groups and add each to our groups array
-                foreach ($all_groups as $group_entry) {
-                    $groups[] .= $group_entry[$map['member']][0];
-                }
+                $groups = $this->getGroupsOpenLdap($attributes);
                 break;
-                                
             default:
+                // Reference the map, just to make the name shorter
+                $map =& $this->attribute_map;
 
                 // Log the general search
                 SimpleSAML\Logger::debug(
@@ -148,8 +102,7 @@ class sspmod_ldap_Auth_Process_AttributeAddUsersGroups extends sspmod_ldap_Auth_
                 if (!isset($attributes[$map['memberof']])) {
                     throw new SimpleSAML_Error_Exception(
                         $this->title . 'The memberof attribute [' . $map['memberof'] .
-                        '] is not defined in the users Attributes: ' . implode(', ', array_keys($attributes))
-                    );
+                        '] is not defined in the user\'s Attributes: ' . implode(', ', array_keys($attributes)));
                 }
 
                 // MemberOf must be an array of group DN's
@@ -172,6 +125,86 @@ class sspmod_ldap_Auth_Process_AttributeAddUsersGroups extends sspmod_ldap_Auth_
     }
 
 
+    /**
+     * OpenLDAP optimized search
+     * using the required attribute values from the user to
+     * get their group membership, recursively.
+     *
+     * @throws SimpleSAML_Error_Exception
+     * @param array $attributes
+     * @return array
+     */
+    protected function getGroupsOpenLdap($attributes)
+    {
+        // Log the OpenLDAP specific search
+        SimpleSAML\Logger::debug(
+            $this->title . 'Searching LDAP using OpenLDAP specific method.'
+        );
+
+        // Reference the map, just to make the name shorter
+        $map =& $this->attribute_map;
+
+        // Print group search string and search for all group names
+        $openldap_base = $this->config->getString('ldap.basedn','ou=groups,dc=example,dc=com');
+        SimpleSAML\Logger::debug(
+            $this->title . "Searching for groups in ldap.basedn ".$openldap_base." with filter (".$map['memberof']."=".$attributes[$map['username']][0].") and attributes ".$map['member']
+        );
+
+        $groups = array();
+        try {
+            // Intention is to filter in 'ou=groups,dc=example,dc=com' for '(memberUid = <value of attribute.username>)' and take only the attributes 'cn' (=name of the group)
+            $all_groups = $this->getLdap()->searchformultiple($openldap_base, array($map['memberof'] => $attributes[$map['username']][0]) , array($map['member']));
+        } catch (SimpleSAML_Error_UserNotFound $e) {
+            return $groups; // if no groups found return with empty (still just initialized) groups array
+        }
+
+        // run through all groups and add each to our groups array
+        foreach ($all_groups as $group_entry) {
+            $groups[] .= $group_entry[$map['member']][0];
+        }
+
+        return $groups;
+    }
+
+
+    /**
+     * Active Directory optimized search
+     * using the required attribute values from the user to
+     * get their group membership, recursively.
+     *
+     * @throws SimpleSAML_Error_Exception
+     * @param array $attributes
+     * @return array
+     */
+    protected function getGroupsActiveDirectory($attributes)
+    {
+        // Log the AD specific search
+        SimpleSAML\Logger::debug(
+            $this->title . 'Searching LDAP using ActiveDirectory specific method.'
+        );
+
+        // Reference the map, just to make the name shorter
+        $map =& $this->attribute_map;
+
+        // Make sure the defined dn attribute exists
+        if (!isset($attributes[$map['dn']])) {
+            throw new SimpleSAML_Error_Exception(
+                $this->title . 'The DN attribute [' . $map['dn'] .
+                '] is not defined in the user\'s Attributes: ' . implode(', ', array_keys($attributes)));
+        }
+
+        // DN attribute must have a value
+        if (!isset($attributes[$map['dn']][0]) || !$attributes[$map['dn']][0]) {
+            throw new SimpleSAML_Error_Exception(
+                $this->title . 'The DN attribute [' . $map['dn'] .
+                '] does not have a [0] value defined. ' . $this->var_export($attributes[$map['dn']])
+            );
+        }
+
+        // Pass to the AD specific search
+        return $this->searchActiveDirectory($attributes[$map['dn']][0]);
+    }
+
     /**
      * Looks for groups from the list of DN's passed. Also
      * recursively searches groups for further membership.
@@ -183,7 +216,7 @@ class sspmod_ldap_Auth_Process_AttributeAddUsersGroups extends sspmod_ldap_Auth_
      */
     protected function search($memberof)
     {
-        assert('is_array($memberof)');
+        assert(is_array($memberof));
 
         // Used to determine what DN's have already been searched
         static $searched = array();
@@ -202,6 +235,14 @@ class sspmod_ldap_Auth_Process_AttributeAddUsersGroups extends sspmod_ldap_Auth_
             ' Group Type: ' . $this->type_map['group']
         );
 
+        // Work out what attributes to get for a group
+        $use_group_name = FALSE;
+        $get_attributes = array($map['memberof'], $map['type']);
+        if (isset($map['name']) && $map['name']) {
+            $get_attributes[] = $map['name'];
+            $use_group_name = TRUE;
+        }
+
         // Check each DN of the passed memberOf
         foreach ($memberof as $dn) {
 
@@ -216,7 +257,7 @@ class sspmod_ldap_Auth_Process_AttributeAddUsersGroups extends sspmod_ldap_Auth_
 
             // Query LDAP for the attribute values for the DN
             try {
-                $attributes = $this->getLdap()->getAttributes($dn, array($map['memberof'], $map['type']));
+                $attributes = $this->getLdap()->getAttributes($dn, $get_attributes);
             } catch (SimpleSAML_Error_AuthSource $e) {
                 continue; // DN must not exist, just continue. Logged by the LDAP object
             }
@@ -227,10 +268,16 @@ class sspmod_ldap_Auth_Process_AttributeAddUsersGroups extends sspmod_ldap_Auth_
             }
 
             // Add to found groups array
-            $groups[] = $dn;
+            if ($use_group_name && isset($attributes[$map['name']]) && is_array($attributes[$map['name']])) {
+                $groups[] = $attributes[$map['name']][0];
+            } else {
+                $groups[] = $dn;
+            }
 
             // Recursively search "sub" groups
-            $groups = array_merge($groups, $this->search($attributes[$map['memberof']]));
+            if (!empty($attributes[$map['memberof']])) {
+                $groups = array_merge($groups, $this->search($attributes[$map['memberof']]));
+            }
         }
 
         // Return only the unique group names
@@ -248,7 +295,7 @@ class sspmod_ldap_Auth_Process_AttributeAddUsersGroups extends sspmod_ldap_Auth_
      */
     protected function searchActiveDirectory($dn)
     {
-        assert('is_string($dn) && $dn != ""');
+        assert(is_string($dn) && $dn != '');
 
         // Shorten the variable name
         $map =& $this->attribute_map;
@@ -286,7 +333,6 @@ class sspmod_ldap_Auth_Process_AttributeAddUsersGroups extends sspmod_ldap_Auth_
 
         // Check each entry..
         foreach ($entries as $entry) {
-
             // Check for the DN using the original attribute name
             if (isset($entry[$map['dn']][0])) {
                 $groups[] = $entry[$map['dn']][0];
