@@ -9,7 +9,7 @@
  */
 
 $state = SimpleSAML_Auth_State::loadState($_REQUEST['AuthState'], sspmod_negotiate_Auth_Source_Negotiate::STAGEID);
-SimpleSAML_Logger::debug('backend - fallback: '.$state['LogoutState']['negotiate:backend']);
+SimpleSAML\Logger::debug('backend - fallback: '.$state['LogoutState']['negotiate:backend']);
 
 sspmod_negotiate_Auth_Source_Negotiate::fallBack($state);
 
