@@ -12,29 +12,35 @@ if (!class_exists('OAuthException')) {
     /*
      * Generic exception class
      */
-    class OAuthException extends Exception {
+    class OAuthException extends Exception
+    {
         // pass
     }
 }
 
 if (!class_exists('OAuthConsumer')) {
-    class OAuthConsumer {
+    class OAuthConsumer
+    {
         public $key;
         public $secret;
+        public $callback_url;
 
-        function __construct($key, $secret, $callback_url=NULL) {
+        public function __construct($key, $secret, $callback_url = null)
+        {
             $this->key = $key;
             $this->secret = $secret;
             $this->callback_url = $callback_url;
         }
 
-        function __toString() {
+        public function __toString()
+        {
             return "OAuthConsumer[key=$this->key,secret=$this->secret]";
         }
     }
 }
 
-class OAuthToken {
+class OAuthToken
+{
     // access tokens and request tokens
     public $key;
     public $secret;
@@ -43,7 +49,8 @@ class OAuthToken {
      * key = the token
      * secret = the token secret
      */
-    function __construct($key, $secret) {
+    public function __construct($key, $secret)
+    {
         $this->key = $key;
         $this->secret = $secret;
     }
@@ -52,7 +59,8 @@ class OAuthToken {
      * generates the basic string serialization of a token that a server
      * would respond to request_token and access_token calls with
      */
-    function to_string() {
+    public function to_string()
+    {
         return "oauth_token=" .
         OAuthUtil::urlencode_rfc3986($this->key) .
         "&oauth_token_secret=" .
@@ -60,7 +68,8 @@ class OAuthToken {
         "&oauth_callback_confirmed=true";
     }
 
-    function __toString() {
+    public function __toString()
+    {
         return $this->to_string();
     }
 }
@@ -69,7 +78,8 @@ class OAuthToken {
  * A class for implementing a Signature Method
  * See section 9 ("Signing Requests") in the spec
  */
-abstract class OAuthSignatureMethod {
+abstract class OAuthSignatureMethod
+{
     /**
      * Needs to return the name of the Signature Method (ie HMAC-SHA1)
      * @return string
@@ -96,7 +106,8 @@ abstract class OAuthSignatureMethod {
      * @param string $signature
      * @return bool
      */
-    public function check_signature($request, $consumer, $token, $signature) {
+    public function check_signature($request, $consumer, $token, $signature)
+    {
         $built = $this->build_signature($request, $consumer, $token);
 
         // Check for zero length, although unlikely here
@@ -125,12 +136,15 @@ abstract class OAuthSignatureMethod {
  * character (ASCII code 38) even if empty.
  *   - Chapter 9.2 ("HMAC-SHA1")
  */
-class OAuthSignatureMethod_HMAC_SHA1 extends OAuthSignatureMethod {
-    function get_name() {
+class OAuthSignatureMethod_HMAC_SHA1 extends OAuthSignatureMethod
+{
+    public function get_name()
+    {
         return "HMAC-SHA1";
     }
 
-    public function build_signature($request, $consumer, $token) {
+    public function build_signature($request, $consumer, $token)
+    {
         $base_string = $request->get_signature_base_string();
         $request->base_string = $base_string;
 
@@ -151,8 +165,10 @@ class OAuthSignatureMethod_HMAC_SHA1 extends OAuthSignatureMethod {
  * over a secure channel such as HTTPS. It does not use the Signature Base String.
  *   - Chapter 9.4 ("PLAINTEXT")
  */
-class OAuthSignatureMethod_PLAINTEXT extends OAuthSignatureMethod {
-    public function get_name() {
+class OAuthSignatureMethod_PLAINTEXT extends OAuthSignatureMethod
+{
+    public function get_name()
+    {
         return "PLAINTEXT";
     }
 
@@ -165,7 +181,8 @@ class OAuthSignatureMethod_PLAINTEXT extends OAuthSignatureMethod {
      * Please note that the second encoding MUST NOT happen in the SignatureMethod, as
      * OAuthRequest handles this!
      */
-    public function build_signature($request, $consumer, $token) {
+    public function build_signature($request, $consumer, $token)
+    {
         $key_parts = array(
             $consumer->secret,
             ($token) ? $token->secret : ""
@@ -187,8 +204,10 @@ class OAuthSignatureMethod_PLAINTEXT extends OAuthSignatureMethod {
  * specification.
  *   - Chapter 9.3 ("RSA-SHA1")
  */
-abstract class OAuthSignatureMethod_RSA_SHA1 extends OAuthSignatureMethod {
-    public function get_name() {
+abstract class OAuthSignatureMethod_RSA_SHA1 extends OAuthSignatureMethod
+{
+    public function get_name()
+    {
         return "RSA-SHA1";
     }
 
@@ -198,15 +217,16 @@ abstract class OAuthSignatureMethod_RSA_SHA1 extends OAuthSignatureMethod {
     // (3) some sort of specific discovery code based on request
     //
     // Either way should return a string representation of the certificate
-    protected abstract function fetch_public_cert(&$request);
+    abstract protected function fetch_public_cert(&$request);
 
     // Up to the SP to implement this lookup of keys. Possible ideas are:
     // (1) do a lookup in a table of trusted certs keyed off of consumer
     //
     // Either way should return a string representation of the certificate
-    protected abstract function fetch_private_cert(&$request);
+    abstract protected function fetch_private_cert(&$request);
 
-    public function build_signature($request, $consumer, $token) {
+    public function build_signature($request, $consumer, $token)
+    {
         $base_string = $request->get_signature_base_string();
         $request->base_string = $base_string;
 
@@ -217,7 +237,7 @@ abstract class OAuthSignatureMethod_RSA_SHA1 extends OAuthSignatureMethod {
         $privatekeyid = openssl_get_privatekey($cert);
 
         // Sign using the key
-        $ok = openssl_sign($base_string, $signature, $privatekeyid);
+        openssl_sign($base_string, $signature, $privatekeyid);
 
         // Release the key resource
         openssl_free_key($privatekeyid);
@@ -225,7 +245,8 @@ abstract class OAuthSignatureMethod_RSA_SHA1 extends OAuthSignatureMethod {
         return base64_encode($signature);
     }
 
-    public function check_signature($request, $consumer, $token, $signature) {
+    public function check_signature($request, $consumer, $token, $signature)
+    {
         $decoded_sig = base64_decode($signature);
 
         $base_string = $request->get_signature_base_string();
@@ -246,7 +267,8 @@ abstract class OAuthSignatureMethod_RSA_SHA1 extends OAuthSignatureMethod {
     }
 }
 
-class OAuthRequest {
+class OAuthRequest
+{
     protected $parameters;
     protected $http_method;
     protected $http_url;
@@ -255,9 +277,10 @@ class OAuthRequest {
     public static $version = '1.0';
     public static $POST_INPUT = 'php://input';
 
-    function __construct($http_method, $http_url, $parameters=NULL) {
+    public function __construct($http_method, $http_url, $parameters = null)
+    {
         $parameters = ($parameters) ? $parameters : array();
-        $parameters = array_merge( OAuthUtil::parse_parameters(parse_url($http_url, PHP_URL_QUERY)), $parameters);
+        $parameters = array_merge(OAuthUtil::parse_parameters(parse_url($http_url, PHP_URL_QUERY)), $parameters);
         $this->parameters = $parameters;
         $this->http_method = $http_method;
         $this->http_url = $http_url;
@@ -267,7 +290,8 @@ class OAuthRequest {
     /**
      * attempt to build up a request from what was passed to the server
      */
-    public static function from_request($http_method=NULL, $http_url=NULL, $parameters=NULL) {
+    public static function from_request($http_method = null, $http_url = null, $parameters = null)
+    {
         $scheme = (!isset($_SERVER['HTTPS']) || $_SERVER['HTTPS'] != "on")
             ? 'http'
             : 'https';
@@ -319,7 +343,8 @@ class OAuthRequest {
     /**
      * pretty much a helper function to set up the request
      */
-    public static function from_consumer_and_token($consumer, $token, $http_method, $http_url, $parameters=NULL) {
+    public static function from_consumer_and_token($consumer, $token, $http_method, $http_url, $parameters = null)
+    {
         $parameters = ($parameters) ?  $parameters : array();
         $defaults = array("oauth_version" => OAuthRequest::$version,
                           "oauth_nonce" => OAuthRequest::generate_nonce(),
@@ -333,7 +358,8 @@ class OAuthRequest {
         return new OAuthRequest($http_method, $http_url, $parameters);
     }
 
-    public function set_parameter($name, $value, $allow_duplicates = true) {
+    public function set_parameter($name, $value, $allow_duplicates = true)
+    {
         if ($allow_duplicates && isset($this->parameters[$name])) {
             // We have already added parameter(s) with this name, so add to the list
             if (is_scalar($this->parameters[$name])) {
@@ -348,15 +374,18 @@ class OAuthRequest {
         }
     }
 
-    public function get_parameter($name) {
+    public function get_parameter($name)
+    {
         return isset($this->parameters[$name]) ? $this->parameters[$name] : null;
     }
 
-    public function get_parameters() {
+    public function get_parameters()
+    {
         return $this->parameters;
     }
 
-    public function unset_parameter($name) {
+    public function unset_parameter($name)
+    {
         unset($this->parameters[$name]);
     }
 
@@ -364,7 +393,8 @@ class OAuthRequest {
      * The request parameters, sorted and concatenated into a normalized string.
      * @return string
      */
-    public function get_signable_parameters() {
+    public function get_signable_parameters()
+    {
         // Grab all parameters
         $params = $this->parameters;
 
@@ -384,7 +414,8 @@ class OAuthRequest {
      * and the parameters (normalized), each urlencoded
      * and the concated with &.
      */
-    public function get_signature_base_string() {
+    public function get_signature_base_string()
+    {
         $parts = array(
             $this->get_normalized_http_method(),
             $this->get_normalized_http_url(),
@@ -399,7 +430,8 @@ class OAuthRequest {
     /**
      * just uppercases the http method
      */
-    public function get_normalized_http_method() {
+    public function get_normalized_http_method()
+    {
         return strtoupper($this->http_method);
     }
 
@@ -407,7 +439,8 @@ class OAuthRequest {
      * parses the url and rebuilds it to be
      * scheme://host/path
      */
-    public function get_normalized_http_url() {
+    public function get_normalized_http_url()
+    {
         $parts = parse_url($this->http_url);
 
         $scheme = (isset($parts['scheme'])) ? $parts['scheme'] : 'http';
@@ -425,7 +458,8 @@ class OAuthRequest {
     /**
      * builds a url usable for a GET request
      */
-    public function to_url() {
+    public function to_url()
+    {
         $post_data = $this->to_postdata();
         $out = $this->get_normalized_http_url();
         if ($post_data) {
@@ -437,24 +471,28 @@ class OAuthRequest {
     /**
      * builds the data one would send in a POST request
      */
-    public function to_postdata() {
+    public function to_postdata()
+    {
         return OAuthUtil::build_http_query($this->parameters);
     }
 
     /**
      * builds the Authorization: header
      */
-    public function to_header($realm=null) {
+    public function to_header($realm = null)
+    {
         $first = true;
-        if($realm) {
+        if ($realm) {
             $out = 'Authorization: OAuth realm="' . OAuthUtil::urlencode_rfc3986($realm) . '"';
             $first = false;
-        } else
+        } else {
             $out = 'Authorization: OAuth';
+        }
 
-        $total = array();
         foreach ($this->parameters as $k => $v) {
-            if (substr($k, 0, 5) != "oauth") continue;
+            if (substr($k, 0, 5) != "oauth") {
+                continue;
+            }
             if (is_array($v)) {
                 throw new OAuthException('Arrays not supported in headers');
             }
@@ -468,12 +506,14 @@ class OAuthRequest {
         return $out;
     }
 
-    public function __toString() {
+    public function __toString()
+    {
         return $this->to_url();
     }
 
 
-    public function sign_request($signature_method, $consumer, $token) {
+    public function sign_request($signature_method, $consumer, $token)
+    {
         $this->set_parameter(
             "oauth_signature_method",
             $signature_method->get_name(),
@@ -483,7 +523,8 @@ class OAuthRequest {
         $this->set_parameter("oauth_signature", $signature, false);
     }
 
-    public function build_signature($signature_method, $consumer, $token) {
+    public function build_signature($signature_method, $consumer, $token)
+    {
         $signature = $signature_method->build_signature($this, $consumer, $token);
         return $signature;
     }
@@ -491,14 +532,16 @@ class OAuthRequest {
     /**
      * util function: current timestamp
      */
-    private static function generate_timestamp() {
+    private static function generate_timestamp()
+    {
         return time();
     }
 
     /**
      * util function: current nonce
      */
-    private static function generate_nonce() {
+    private static function generate_nonce()
+    {
         $mt = microtime();
         $rand = mt_rand();
 
@@ -506,18 +549,21 @@ class OAuthRequest {
     }
 }
 
-class OAuthServer {
+class OAuthServer
+{
     protected $timestamp_threshold = 300; // in seconds, five minutes
     protected $version = '1.0';             // hi blaine
     protected $signature_methods = array();
 
     protected $data_store;
 
-    function __construct($data_store) {
+    public function __construct($data_store)
+    {
         $this->data_store = $data_store;
     }
 
-    public function add_signature_method($signature_method) {
+    public function add_signature_method($signature_method)
+    {
         $this->signature_methods[$signature_method->get_name()] =
             $signature_method;
     }
@@ -528,7 +574,8 @@ class OAuthServer {
      * process a request_token request
      * returns the request token on success
      */
-    public function fetch_request_token(&$request) {
+    public function fetch_request_token(&$request)
+    {
         $this->get_version($request);
 
         $consumer = $this->get_consumer($request);
@@ -549,7 +596,8 @@ class OAuthServer {
      * process an access_token request
      * returns the access token on success
      */
-    public function fetch_access_token(&$request) {
+    public function fetch_access_token(&$request)
+    {
         $this->get_version($request);
 
         $consumer = $this->get_consumer($request);
@@ -569,7 +617,8 @@ class OAuthServer {
     /**
      * verify an api call, checks all the parameters
      */
-    public function verify_request(&$request) {
+    public function verify_request(&$request)
+    {
         $this->get_version($request);
         $consumer = $this->get_consumer($request);
         $token = $this->get_token($request, $consumer, "access");
@@ -581,7 +630,8 @@ class OAuthServer {
     /**
      * version 1
      */
-    private function get_version(&$request) {
+    private function get_version(&$request)
+    {
         $version = $request->get_parameter("oauth_version");
         if (!$version) {
             // Service Providers MUST assume the protocol version to be 1.0 if this parameter is not present.
@@ -597,7 +647,8 @@ class OAuthServer {
     /**
      * figure out the signature with some defaults
      */
-    private function get_signature_method($request) {
+    private function get_signature_method($request)
+    {
         $signature_method = $request instanceof OAuthRequest
             ? $request->get_parameter("oauth_signature_method")
             : NULL;
@@ -622,7 +673,8 @@ class OAuthServer {
     /**
      * try to find the consumer for the provided request's consumer key
      */
-    private function get_consumer($request) {
+    private function get_consumer($request)
+    {
         $consumer_key = $request instanceof OAuthRequest
             ? $request->get_parameter("oauth_consumer_key")
             : NULL;
@@ -642,10 +694,11 @@ class OAuthServer {
     /**
      * try to find the token for the provided request's token key
      */
-    private function get_token($request, $consumer, $token_type="access") {
+    private function get_token($request, $consumer, $token_type="access")
+    {
         $token_field = $request instanceof OAuthRequest
             ? $request->get_parameter('oauth_token')
-            : NULL;
+            : null;
 
         if (!empty($token_field)) {
             $token = $this->data_store->lookup_token(
@@ -665,14 +718,15 @@ class OAuthServer {
      * all-in-one function to check the signature on a request
      * should guess the signature method appropriately
      */
-    private function check_signature($request, $consumer, $token) {
+    private function check_signature($request, $consumer, $token)
+    {
         // this should probably be in a different method
         $timestamp = $request instanceof OAuthRequest
             ? $request->get_parameter('oauth_timestamp')
-            : NULL;
+            : null;
         $nonce = $request instanceof OAuthRequest
             ? $request->get_parameter('oauth_nonce')
-            : NULL;
+            : null;
 
         $this->check_timestamp($timestamp);
         $this->check_nonce($consumer, $token, $nonce, $timestamp);
@@ -695,11 +749,13 @@ class OAuthServer {
     /**
      * check that the timestamp is new enough
      */
-    private function check_timestamp($timestamp) {
-        if( ! $timestamp )
+    private function check_timestamp($timestamp)
+    {
+        if (!$timestamp) {
             throw new OAuthException(
                 'Missing timestamp parameter. The parameter is required'
             );
+        }
 
         // verify that timestamp is recentish
         $now = time();
@@ -713,11 +769,13 @@ class OAuthServer {
     /**
      * check that the nonce is not repeated
      */
-    private function check_nonce($consumer, $token, $nonce, $timestamp) {
-        if( ! $nonce )
+    private function check_nonce($consumer, $token, $nonce, $timestamp)
+    {
+        if (!$nonce) {
             throw new OAuthException(
                 'Missing nonce parameter. The parameter is required'
             );
+        }
 
         // verify that the nonce is uniqueish
         $found = $this->data_store->lookup_nonce(
@@ -730,27 +788,32 @@ class OAuthServer {
             throw new OAuthException("Nonce already used: $nonce");
         }
     }
-
 }
 
-class OAuthDataStore {
-    function lookup_consumer($consumer_key) {
+class OAuthDataStore
+{
+    public function lookup_consumer($consumer_key)
+    {
         // implement me
     }
 
-    function lookup_token($consumer, $token_type, $token) {
+    public function lookup_token($consumer, $token_type, $token)
+    {
         // implement me
     }
 
-    function lookup_nonce($consumer, $token, $nonce, $timestamp) {
+    public function lookup_nonce($consumer, $token, $nonce, $timestamp)
+    {
         // implement me
     }
 
-    function new_request_token($consumer, $callback = null) {
+    public function new_request_token($consumer, $callback = null)
+    {
         // return a new token attached to this consumer
     }
 
-    function new_access_token($token, $consumer, $verifier = null) {
+    public function new_access_token($token, $consumer, $verifier = null)
+    {
         // return a new access token attached to this consumer
         // for the user associated with this token if the request token
         // is authorized
@@ -759,8 +822,10 @@ class OAuthDataStore {
 
 }
 
-class OAuthUtil {
-    public static function urlencode_rfc3986($input) {
+class OAuthUtil
+{
+    public static function urlencode_rfc3986($input)
+    {
         if (is_array($input)) {
             return array_map(array('OAuthUtil', 'urlencode_rfc3986'), $input);
         } else if (is_scalar($input)) {
@@ -778,7 +843,8 @@ class OAuthUtil {
     // This decode function isn't taking into consideration the above
     // modifications to the encoding process. However, this method doesn't
     // seem to be used anywhere so leaving it as is.
-    public static function urldecode_rfc3986($string) {
+    public static function urldecode_rfc3986($string)
+    {
         return urldecode($string);
     }
 
@@ -787,7 +853,8 @@ class OAuthUtil {
     // Can filter out any non-oauth parameters if needed (default behaviour)
     // May 28th, 2010 - method updated to tjerk.meesters for a speed improvement.
     //                  see http://code.google.com/p/oauth/issues/detail?id=163
-    public static function split_header($header, $only_allow_oauth_parameters = true) {
+    public static function split_header($header, $only_allow_oauth_parameters = true)
+    {
         $params = array();
         if (preg_match_all('/('.($only_allow_oauth_parameters ? 'oauth_' : '').'[a-z_-]*)=(:?"([^"]*)"|([^,]*))/', $header, $matches)) {
             foreach ($matches[1] as $i => $h) {
@@ -801,7 +868,8 @@ class OAuthUtil {
     }
 
     // helper to try to sort out headers for people who aren't running apache
-    public static function get_headers() {
+    public static function get_headers()
+    {
         if (function_exists('apache_request_headers')) {
             // we need this to get the actual Authorization: header
             // because apache tends to tell us it doesn't exist
@@ -812,7 +880,7 @@ class OAuthUtil {
             // returns the headers in the same case as they are in the
             // request
             $out = array();
-            foreach ($headers AS $key => $value) {
+            foreach ($headers as $key => $value) {
                 $key = str_replace(
                     " ",
                     "-",
@@ -824,10 +892,12 @@ class OAuthUtil {
             // otherwise we don't have apache and are just going to have to hope
             // that $_SERVER actually contains what we need
             $out = array();
-            if( isset($_SERVER['CONTENT_TYPE']) )
+            if (isset($_SERVER['CONTENT_TYPE'])) {
                 $out['Content-Type'] = $_SERVER['CONTENT_TYPE'];
-            if( isset($_ENV['CONTENT_TYPE']) )
+            }
+            if (isset($_ENV['CONTENT_TYPE'])) {
                 $out['Content-Type'] = $_ENV['CONTENT_TYPE'];
+            }
 
             foreach ($_SERVER as $key => $value) {
                 if (substr($key, 0, 5) == "HTTP_") {
@@ -853,8 +923,11 @@ class OAuthUtil {
     // This function takes a input like a=b&a=c&d=e and returns the parsed
     // parameters like this
     // array('a' => array('b','c'), 'd' => 'e')
-    public static function parse_parameters( $input ) {
-        if (!isset($input) || !$input) return array();
+    public static function parse_parameters($input)
+    {
+        if (!isset($input) || !$input) {
+            return array();
+        }
 
         $pairs = explode('&', $input);
 
@@ -882,8 +955,11 @@ class OAuthUtil {
         return $parsed_parameters;
     }
 
-    public static function build_http_query($params) {
-        if (!$params) return '';
+    public static function build_http_query($params)
+    {
+        if (!$params) {
+            return '';
+        }
 
         // Urlencode both keys and values
         $keys = OAuthUtil::urlencode_rfc3986(array_keys($params));
