@@ -1,25 +1,24 @@
 <?php
 
-/* Load simpleSAMLphp, configuration and metadata */
+// Load SimpleSAMLphp, configuration and metadata
 $config = SimpleSAML_Configuration::getInstance();
 $session = SimpleSAML_Session::getSessionFromRequest();
 $oauthconfig = SimpleSAML_Configuration::getOptionalConfig('module_oauth.php');
 
 $store = new sspmod_core_Storage_SQLPermanentStorage('oauth');
 
-//$authsource = $oauthconfig->getValue('auth', 'admin');
 $authsource = "admin";	// force admin to authenticate as registry maintainer
 $useridattr = $oauthconfig->getValue('useridattr', 'user');
-//$useridattr = $oauthconfig->getValue('useridattr', 'uid');
 
 if ($session->isValid($authsource)) {
-	$attributes = $session->getAttributes();
+	$attributes = $session->getAuthData($authsource, 'Attributes');
 	// Check if userid exists
 	if (!isset($attributes[$useridattr])) 
 		throw new Exception('User ID is missing');
 	$userid = $attributes[$useridattr][0];
 } else {
-	SimpleSAML_Auth_Default::initLogin($authsource, SimpleSAML_Utilities::selfURL());
+	$as = SimpleSAML_Auth_Source::getById($authsource);
+	$as->initLogin(\SimpleSAML\Utils\HTTP::getSelfURL());
 }
 
 function requireOwnership($entry, $userid) {
@@ -37,8 +36,8 @@ if (array_key_exists('editkey', $_REQUEST)) {
 } else {
 	$entry = array(
 		'owner' => $userid,
-		'key' => SimpleSAML_Utilities::generateID(),
-		'secret' => SimpleSAML_Utilities::generateID(),
+		'key' => SimpleSAML\Utils\Random::generateID(),
+		'secret' => SimpleSAML\Utils\Random::generateID(),
 	);
 }
 
@@ -52,9 +51,7 @@ if (isset($_POST['submit'])) {
 	$entry = $editor->formToMeta($_POST, array(), array('owner' => $userid));
 
 	requireOwnership($entry, $userid);
-	
-#	echo('<pre>Created: '); print_r($entry); exit;
-	
+
 	$store->set('consumers', $entry['key'], '', $entry);
 	
 	$template = new SimpleSAML_XHTML_Template($config, 'oauth:registry.saved.php');
