@@ -6,9 +6,9 @@
  */
 function statistics_hook_cron(&$croninfo)
 {
-    assert('is_array($croninfo)');
-    assert('array_key_exists("summary", $croninfo)');
-    assert('array_key_exists("tag", $croninfo)');
+    assert(is_array($croninfo));
+    assert(array_key_exists('summary', $croninfo));
+    assert(array_key_exists('tag', $croninfo));
 
     $statconfig = SimpleSAML_Configuration::getConfig('module_statistics.php');
 	
