@@ -6,9 +6,9 @@
  */
 function statistics_hook_sanitycheck(&$hookinfo)
 {
-    assert('is_array($hookinfo)');
-    assert('array_key_exists("errors", $hookinfo)');
-    assert('array_key_exists("info", $hookinfo)');
+    assert(is_array($hookinfo));
+    assert(array_key_exists('errors', $hookinfo));
+    assert(array_key_exists('info', $hookinfo));
 
     try {
         $statconfig = SimpleSAML_Configuration::getConfig('module_statistics.php');
