@@ -1,5 +1,5 @@
 <?php
-$this->data['header'] = $this->t('metadata_'.$this->data['header']);
+$this->data['header'] = $this->t($this->data['headerString']);
 $this->includeAtTemplateBase('includes/header.php'); ?>
     <h2><?php echo $this->data['header']; ?></h2>
     <p><?php echo $this->t('metadata_intro'); ?></p>
@@ -44,7 +44,7 @@ if (array_key_exists('available_certs', $this->data)) { ?>
 <?php
     foreach (array_keys($this->data['available_certs']) as $certName) {
         echo '<li><a href="'.
-            htmlspecialchars(SimpleSAML_Module::getModuleURL('saml/idp/certs.php').'/'.$certName).'">'.$certName.
+            htmlspecialchars(SimpleSAML\Module::getModuleURL('saml/idp/certs.php').'/'.$certName).'">'.$certName.
             '</a>';
 
         if ($this->data['available_certs'][$certName]['certFingerprint'][0] ===
